==> knative-model-6.0.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecBuilder;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecFluent;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;

 /**
  * Generated
  */
public interface KafkaChannelSpecFluent<A extends KafkaChannelSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery();
  public DeliverySpec buildDelivery();
  public A withDelivery(DeliverySpec delivery);
  public Boolean hasDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> withNewDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
  public KafkaChannelSpecFluent.DeliveryNested<A> editDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> editOrNewDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);
  public Integer getNumPartitions();
  public A withNumPartitions(Integer numPartitions);
  public Boolean hasNumPartitions();
  public Integer getReplicationFactor();
  public A withReplicationFactor(Integer replicationFactor);
  public Boolean hasReplicationFactor();
  public A addToSubscribers(Integer index,SubscriberSpec item);
  public A setToSubscribers(Integer index,SubscriberSpec item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items);
  public A addAllToSubscribers(Collection<SubscriberSpec> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items);
  public A removeAllFromSubscribers(Collection<SubscriberSpec> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberSpec> getSubscribers();
  public List<SubscriberSpec> buildSubscribers();
  public SubscriberSpec buildSubscriber(Integer index);
  public SubscriberSpec buildFirstSubscriber();
  public SubscriberSpec buildLastSubscriber();
  public SubscriberSpec buildMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public A withSubscribers(List<SubscriberSpec> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... subscribers);
  public Boolean hasSubscribers();
  public KafkaChannelSpecFluent.SubscribersNested<A> addNewSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberSpec item);
  public KafkaChannelSpecFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberSpec item);
  public KafkaChannelSpecFluent.SubscribersNested<A> editSubscriber(Integer index);
  public KafkaChannelSpecFluent.SubscribersNested<A> editFirstSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> editLastSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public interface DeliveryNested<N> extends Nested<N>,DeliverySpecFluent<KafkaChannelSpecFluent.DeliveryNested<N>>{
    public N and();
    public N endDelivery();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberSpecFluent<KafkaChannelSpecFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}

==> knative-model-6.1.0-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaChannelSpecFluent.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecBuilder;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpecFluent;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;

 /**
  * Generated
  */
public interface KafkaChannelSpecFluent<A extends KafkaChannelSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDelivery instead.
   * @return The buildable object.
   */
  @Deprecated
  public DeliverySpec getDelivery();
  public DeliverySpec buildDelivery();
  public A withDelivery(DeliverySpec delivery);
  public Boolean hasDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> withNewDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> withNewDeliveryLike(DeliverySpec item);
  public KafkaChannelSpecFluent.DeliveryNested<A> editDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> editOrNewDelivery();
  public KafkaChannelSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(DeliverySpec item);
  public Integer getNumPartitions();
  public A withNumPartitions(Integer numPartitions);
  public Boolean hasNumPartitions();
  public Integer getReplicationFactor();
  public A withReplicationFactor(Integer replicationFactor);
  public Boolean hasReplicationFactor();
  public String getRetentionDuration();
  public A withRetentionDuration(String retentionDuration);
  public Boolean hasRetentionDuration();
  public A addToSubscribers(Integer index,SubscriberSpec item);
  public A setToSubscribers(Integer index,SubscriberSpec item);
  public A addToSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items);
  public A addAllToSubscribers(Collection<SubscriberSpec> items);
  public A removeFromSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... items);
  public A removeAllFromSubscribers(Collection<SubscriberSpec> items);
  public A removeMatchingFromSubscribers(Predicate<SubscriberSpecBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSubscribers instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<SubscriberSpec> getSubscribers();
  public List<SubscriberSpec> buildSubscribers();
  public SubscriberSpec buildSubscriber(Integer index);
  public SubscriberSpec buildFirstSubscriber();
  public SubscriberSpec buildLastSubscriber();
  public SubscriberSpec buildMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public Boolean hasMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public A withSubscribers(List<SubscriberSpec> subscribers);
  public A withSubscribers(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.SubscriberSpec... subscribers);
  public Boolean hasSubscribers();
  public KafkaChannelSpecFluent.SubscribersNested<A> addNewSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> addNewSubscriberLike(SubscriberSpec item);
  public KafkaChannelSpecFluent.SubscribersNested<A> setNewSubscriberLike(Integer index,SubscriberSpec item);
  public KafkaChannelSpecFluent.SubscribersNested<A> editSubscriber(Integer index);
  public KafkaChannelSpecFluent.SubscribersNested<A> editFirstSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> editLastSubscriber();
  public KafkaChannelSpecFluent.SubscribersNested<A> editMatchingSubscriber(Predicate<SubscriberSpecBuilder> predicate);
  public interface DeliveryNested<N> extends Nested<N>,DeliverySpecFluent<KafkaChannelSpecFluent.DeliveryNested<N>>{
    public N and();
    public N endDelivery();
    
  }
  public interface SubscribersNested<N> extends Nested<N>,SubscriberSpecFluent<KafkaChannelSpecFluent.SubscribersNested<N>>{
    public N and();
    public N endSubscriber();
    
  }
  
}
